@@ -4,11 +4,11 @@ import pandas as pd
 
 class AnovaLikeModel():
 
-    def __init__(self, signal_type = 'ls', mixing_type = 'mean', number_per_year=252):
+    def __init__(self, signal_action_type = 'ls', mixing_type = 'mean', number_per_year=252):
         self.model = 'anova_like_model'
         self.columns_to_keep = []
         self.median_values = []
-        self.signal_type = signal_type
+        self.signal_action_type = signal_action_type
         self.mixing_type = mixing_type
 
     def fit(self, X_train, y_train, X_val, y_val):#, method = 'standard'):
@@ -20,9 +20,9 @@ class AnovaLikeModel():
     def predict(self, X_test):
         predictions = (X_test[self.columns_to_keep] >= self.median_values).astype(int)
 
-        if self.signal_type == 'lo':
+        if self.signal_action_type == 'lo':
             None
-        if self.signal_type == 'ls':
+        if self.signal_action_type == 'ls':
             predictions = predictions.replace({0: -1})
         if self.mixing_type == 'mean':
             y_pred = predictions.mean(axis=1)
