@@ -684,8 +684,9 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
     while np.isnan(wh.at[wh.index[starting_index], 'wallet_balance']) == True:
         starting_index = starting_index + 1
 
+    initial_pnl = wh.at[wh.index[starting_index], 'realized_pnl']
 
-    wh.at[wh.index[starting_index], 'realized_pnl'] = wh.at[wh.index[starting_index], 'wallet_balance']
+    wh.at[wh.index[starting_index], 'realized_pnl'] = wh.at[wh.index[starting_index], 'wallet_balance']+initial_pnl
     wh.at[wh.index[starting_index], 'fut_transfer_usdt_amount'] = 0.
 
 
@@ -697,7 +698,7 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
 
     wh = wh.drop(columns=['fut_transfer_usdt_amount'])
     td = pd.merge(td, wh, how='left', left_on='date', right_on='date')
-    if fut_transfers_old is not None:
+    if fut_transfers is not None:
         td['bench'] = 1.
 
         fut_transfers_old = pd.merge(fut_transfers_old, td[['date', 'bench']], how='outer', left_on='date', right_on='date')
